==> jijzept-0.13.1-cp310-cp310-macosx_10_16_x86_64.whl: jijzept/post_api.py <==
import logging, os, sys, time

from logging import getLogger
from typing import Any, Dict, Optional, Type, TypeVar

from jijmodeling.sampleset import SolvingTime, SystemTime
from jijmodeling.utils import with_measuring_time

from jijzept.client import JijZeptClient
from jijzept.response import APIStatus, BaseResponse, JijModelingResponse

ResponseType = TypeVar("ResponseType", bound=BaseResponse)

logger = getLogger(__name__)
handler = logging.StreamHandler(sys.stdout)
logger.addHandler(handler)
if os.environ.get("JIJZEPT_VERBOSE") is not None:
    logger.setLevel(logging.INFO)

# set the default timeout to 60 min if not specified.
DEFAULT_TIMEOUT_SEC = 3600


class JijZeptAPIError(Exception):
    pass


def post_instance_and_query(
    ResponseType: Type[TypeVar("ResponseType", bound="BaseResponse")],
    client: JijZeptClient,
    instance_type: str,
    instance: Dict[str, Any],
    queue_name: str,
    solver: str,
    parameters: dict,
    timeout: Optional[float],
    sync: bool = True,
):
    """Low-level API for sending instance and solve request to JijZept.

    Args:
        client (JijZeptClient): JijZept client object
        instance_type (str): instance type
        instance (Dict[str, Any]): serialized instance object.
        queue_name (str): queue_name that specifies which solver the request to be sent to.
        solver (str): solver string that is used in JijZept solvers.
        parameters (dict): additional parameters to be sent to JijZept solvers.
        timeout (Optional[float]): solver timeout [second]
        ResponseType (Type[TypeVar, optional): Response Type. Defaults to "BaseResponse")].
        sync (bool, optional): set sync model. if True, this function does polling until the solution status is changed from `PENDING` or `RUNNING`. Defaults to True.

    Returns:
        ResponseType: response object
    """
    system_time = SystemTime()

    # Instance を投げる
    logger.info("uploading instance ...")
    instance_id = client.post_instance(instance_type, instance, system_time=system_time)

    # Solverにqueryをなげる
    logger.info("submitting query ...")
    actual_timeout = DEFAULT_TIMEOUT_SEC if timeout is None else timeout
    solver_res = client.submit_solve_query(
        queue_name,
        solver,
        parameters,
        instance_id,
        actual_timeout,
        system_time=system_time,
    )
    logger.info(f"submitted to the queue.")
    logger.info(f'Your solution_id is {solver_res["solution_id"]}.')

    if sync:
        response = _fetch_result(
            ResponseType, client, solver_res, system_time=system_time
        )
        if isinstance(response, ResponseType):
            return response
        else:
            res_obj = _from_json_obj(ResponseType, response, system_time=system_time)
            # if isinstance(res_obj, DimodResponse):
            #     popped_solving_time = res_obj.info.pop("solving_time", {})
            #     solving_time = (
            #         popped_solving_time if isinstance(popped_solving_time, dict) else {}
            #     )
            #     measuring_time = MeasuringTime(
            #         solve=SolvingTime(solving_time),
            #         system=system_time,
            #     )
            #     res_obj.info["measuring_time"] = asdict(measuring_time)
            if isinstance(res_obj, JijModelingResponse):
                if res_obj.measuring_time.solve is None:
                    res_obj.measuring_time.solve = SolvingTime()
                res_obj.measuring_time.system = system_time
            return res_obj

    else:
        return ResponseType.empty_response(
            APIStatus.PENDING, client, solver_res["solution_id"]
        )


@with_measuring_time("fetch_result")
def _fetch_result(ResponseType, client, solver_res):
    status = "PENDING"
    show_running_flag = False

    polling_count = 0
    while (status == APIStatus.PENDING.value) or (status == APIStatus.RUNNING.value):
        response = client.fetch_result(solver_res["solution_id"])
        status = response["status"]
        if response["status"] == APIStatus.RUNNING.value and show_running_flag == False:
            logger.info("running...")
            show_running_flag = True
        elif response["status"] == APIStatus.SUCCESS.value:
            return response
        elif response["status"] == APIStatus.FAILED.value:
            return ResponseType.empty_response(
                APIStatus.FAILED,
                client,
                solver_res["solution_id"],
                err_dict=response["solution"],
            )
        elif response["status"] == APIStatus.UNKNOWNERROR.value:
            return ResponseType.empty_response(
                APIStatus.UNKNOWNERROR, client, solver_res["solution_id"]
            )
        time.sleep(2)
        polling_count = polling_count + 1
        if polling_count == 10:
            # show hints if polling is repeated certain times
            logger.info(f"It takes a lot of time to get the solution...")


@with_measuring_time("deserialize_solution")
def _from_json_obj(ResponseType, response):
    res_obj = ResponseType.from_json_obj(response["solution"])
    res_obj.set_status(APIStatus.SUCCESS)
    return res_obj

==> jijzept-1.10.13-cp310-cp310-macosx_11_0_x86_64.whl: jijzept/post_api.py <==
import logging, sys, time

from dataclasses import asdict
from logging import getLogger
from typing import Any, Dict, Optional, Type, TypeVar

from jijmodeling.sampleset import MeasuringTime, SolvingTime, SystemTime
from jijmodeling.utils import with_measuring_time

from jijzept.client import JijZeptClient
from jijzept.response import APIStatus, BaseResponse, DimodResponse
from jijzept.response.jmresponse import JijModelingResponse

ResponseType = TypeVar("ResponseType", bound=BaseResponse)

logger = getLogger(__name__)
handler = logging.StreamHandler(sys.stdout)
logger.addHandler(handler)
logger.setLevel(logging.INFO)

# set the default timeout to 60 min if not specified.
DEFAULT_TIMEOUT_SEC = 3600


def post_instance_and_query(
    ResponseType: Type[TypeVar("ResponseType", bound="BaseResponse")],
    client: JijZeptClient,
    instance_type: str,
    instance: Dict[str, Any],
    queue_name: str,
    solver: str,
    parameters: dict,
    timeout: Optional[float],
    sync: bool = True,
):
    system_time = SystemTime()

    # Instance を投げる
    logger.info("uploading instance ...")
    instance_id = client.post_instance(instance_type, instance, system_time=system_time)

    # Solverにqueryをなげる
    logger.info("submitting query ...")
    actual_timeout = DEFAULT_TIMEOUT_SEC if timeout is None else timeout
    solver_res = client.submit_solve_query(
        queue_name,
        solver,
        parameters,
        instance_id,
        actual_timeout,
        system_time=system_time,
    )
    logger.info(f"submitted to the queue.")
    logger.info(f'Your solution_id is {solver_res["solution_id"]}.')

    if sync:
        response = _fetch_result(
            ResponseType, client, solver_res, system_time=system_time
        )
        if isinstance(response, ResponseType):
            return response
        else:
            res_obj = _from_json_obj(ResponseType, response, system_time=system_time)
            if isinstance(res_obj, DimodResponse):
                measuring_time = MeasuringTime(
                    solve=SolvingTime(**res_obj.info.pop("solving_time", {})),
                    system=system_time,
                )
                res_obj.info["measuring_time"] = asdict(measuring_time)
            elif isinstance(res_obj, JijModelingResponse):
                if res_obj.measuring_time.solve is None:
                    res_obj.measuring_time.solve = SolvingTime()
                res_obj.measuring_time.system = system_time
            return res_obj

    else:
        logger.info(f"You can access the solution by")
        logger.info(f">>> a = XXXSampler(config=...)")
        logger.info(f'>>> a.get_result("{solver_res["solution_id"]}")')
        return ResponseType.empty_response(
            APIStatus.PENDING, client, solver_res["solution_id"]
        )


@with_measuring_time("fetch_result")
def _fetch_result(ResponseType, client, solver_res):
    # 同期モードで解を取得
    status = "PENDING"
    show_running_flag = False

    polling_count = 0
    while (status == APIStatus.PENDING.value) or (status == APIStatus.RUNNING.value):
        response = client.fetch_result(solver_res["solution_id"])
        status = response["status"]
        if response["status"] == APIStatus.RUNNING.value and show_running_flag == False:
            logger.info("running...")
            show_running_flag = True
        elif response["status"] == APIStatus.SUCCESS.value:
            return response
        elif response["status"] == APIStatus.FAILED.value:
            return ResponseType.empty_response(
                APIStatus.FAILED,
                client,
                solver_res["solution_id"],
                err_dict=response["solution"],
            )
        elif response["status"] == APIStatus.UNKNOWNERROR.value:
            return ResponseType.empty_response(
                APIStatus.UNKNOWNERROR, client, solver_res["solution_id"]
            )
        time.sleep(2)
        polling_count = polling_count + 1
        if polling_count == 10:
            # show hints if polling is repeated certain times
            logger.info(f"It takes a lot of time to get the solution...")
            logger.info(f"You can also access the solution by")
            logger.info(f">>> a = XXXSampler(config=...)")
            logger.info(f'>>> a.get_result("{solver_res["solution_id"]}")')


@with_measuring_time("deserialize_solution")
def _from_json_obj(ResponseType, response):
    res_obj = ResponseType.from_json_obj(response["solution"])
    res_obj.set_status(APIStatus.SUCCESS)
    return res_obj
